@@ -11,6 +11,7 @@ import os
 import re
 import uuid
 import zlib
+from copy import deepcopy
 
 from construct import Container, ChecksumError
 from lxml import etree
@@ -24,8 +25,15 @@ from pykeepass.kdbx_parsing.kdbx import KDBX
 from pykeepass.kdbx_parsing.kdbx4 import kdf_uuids
 from pykeepass.xpath import attachment_xp, entry_xp, group_xp, path_xp
 
+logging.basicConfig()
 logger = logging.getLogger(__name__)
 
+
+BLANK_DATABASE_FILENAME = "blank_database.kdbx"
+BLANK_DATABASE_LOCATION = os.path.join(os.path.dirname(os.path.realpath(__file__)), BLANK_DATABASE_FILENAME)
+BLANK_DATABASE_PASSWORD = "password"
+
+
 # FIXME python2
 @python_2_unicode_compatible
 class PyKeePass(object):
@@ -68,15 +76,13 @@ class PyKeePass(object):
         if not filename:
             filename = self.filename
 
-        with open(filename, 'wb') as f:
-            f.write(
-                KDBX.build(
-                    self.kdbx,
-                    password=self.password,
-                    keyfile=self.keyfile,
-                    transformed_key=transformed_key
-                )
-            )
+        KDBX.build_file(
+            self.kdbx,
+            filename,
+            password=self.password,
+            keyfile=self.keyfile,
+            transformed_key=transformed_key
+        )
 
     @property
     def version(self):
@@ -215,6 +221,10 @@ class PyKeePass(object):
             if 'uuid' in kwargs.keys():
                 kwargs['uuid'] = base64.b64encode(kwargs['uuid'].bytes).decode('utf-8')
 
+            # convert tags to semicolon separated string before building xpath
+            if 'tags' in kwargs.keys():
+                kwargs['tags'] = ';'.join(kwargs['tags'])
+
             # build xpath to filter results with specified attributes
             for key, value in kwargs.items():
                 if key not in keys_xp[regex].keys():
@@ -555,3 +565,15 @@ class PyKeePass(object):
         )
         for reference in binaries_gt:
             reference.id = reference.id - 1
+
+
+def create_database(filename, password=None, keyfile=None, transformed_key=None):
+    keepass_instance = PyKeePass(BLANK_DATABASE_LOCATION, BLANK_DATABASE_PASSWORD)
+
+    keepass_instance.filename = filename
+    keepass_instance.password = password
+    keepass_instance.keyfile = keyfile
+
+    keepass_instance.save(transformed_key)
+
+    return keepass_instance
